Crate agent_deploy_contract

Crate agent_deploy_contract 

Stable, transport-neutral deploy consumer contract. This crate intentionally has no HTTP, SQL, async-runtime, or provider dependency.

Modules

paths

Structs

ActivateReleaseRequest
Application
ApprovalRequest
Artifact
BindRuntimeRequest
BindingPage
BuildSpec
CanaryConfig
CancelDeploymentRequest
CreateApplicationRequest
CreateDeploymentRequest
CreateEnvironmentRequest
CreateRuntimeRepositoryRequest
CreateRuntimeTemplateRequest
CreateSandboxRequest
CursorPage
DeleteApplicationRequest
DeleteResult
DeleteRuntimeTemplateRequest
Deployment
Environment
ErrorEnvelope
ExternalBuildAdminConfig
Connection state for an optional externally managed build and deployment service.
ExternalBuildDeploySpec
FmsAdminConfig
GetOperationRequest
GitlabAdminConfig
InfraError
InitializeRuntimeTemplateRequest
ListLogsRequest
LogChunk
LookupBindingQuery
MoulinAdminConfig
Operation
OwnerRef
PromoteReleaseRequest
Promotion
ProviderResource
Release
ResumeDeploymentRequest
RollbackDeploymentRequest
RollingConfig
RouteBinding
RuntimeRepository
RuntimeRepositoryRecord
RuntimeSandboxBinding
RuntimeTemplate
SandboxPage
SandboxView
SecretRef
SnapshotPage
SnapshotView
SourceRevision
TenantProjectScope
UpdateApplicationRequest
UpdateExternalBuildAdminConfigRequest
UpdateFmsAdminConfigRequest
UpdateGitlabAdminConfigRequest
UpdateMoulinAdminConfigRequest
UpdateRuntimeTemplateRequest
UploadedSourceBundle
An immutable source archive accepted by the deploy control plane. source_id is content-addressed and can be supplied in SourceRevision to deploy without granting the service access to a Git repository.

Enums

ArtifactPolicyState
BuildBackend
DeploymentPhase
DeploymentStatus
DeploymentStrategy
ErrorCategory
GitLabVisibility
LogStream
OperationState
OwnerKind
OwnerValidationError
PromotionState
ProviderResourceKind
Provider-owned assets projected into Deploy’s tenant ownership boundary.
RuntimeRepositoryStatus

Constants

BINDINGS_PATH
BINDING_BY_RUNTIME_PATH
BINDING_PATH
IDEMPOTENCY_CONFLICT
RUNTIME_TEMPLATE_GIT_REF
SANDBOXES_PATH
SANDBOX_PATH
SNAPSHOTS_PATH
VERSION_CONFLICT

Functions

normalize_owners
owners_intersect
parse_provider_backend
provider_backend_name

Type Aliases

ApplicationPage
DeploymentPage
LogPage
ProviderResourcePage
ReleasePage
RuntimeRepositoryRecordPage
RuntimeTemplatePage