Crate agent_deploy_contract

Crate agent_deploy_contract 

Stable, transport-neutral deploy consumer contract. This crate intentionally has no HTTP, SQL, async-runtime, or provider dependency.

Modules

paths

Structs

ActivateReleaseRequest
Application
ApprovalRequest
Artifact
BuildSpec
CanaryConfig
CancelDeploymentRequest
CreateApplicationRequest
CreateDeploymentRequest
CreateEnvironmentRequest
CreateRuntimeRepositoryRequest
CreateRuntimeTemplateRequest
CursorPage
DeleteApplicationRequest
DeleteResult
DeleteRuntimeTemplateRequest
Deployment
Environment
ErrorEnvelope
FmsAdminConfig
GetOperationRequest
GitlabAdminConfig
InfraError
InitializeRuntimeTemplateRequest
ListLogsRequest
LogChunk
LubanAdminConfig
LubanDeploySpec
MoulinAdminConfig
Operation
OwnerRef
PromoteReleaseRequest
Promotion
ProviderResource
Release
ResumeDeploymentRequest
RollbackDeploymentRequest
RollingConfig
RouteBinding
RuntimeRepository
RuntimeRepositoryRecord
RuntimeTemplate
SecretRef
SourceRevision
UpdateApplicationRequest
UpdateFmsAdminConfigRequest
UpdateGitlabAdminConfigRequest
UpdateLubanAdminConfigRequest
UpdateMoulinAdminConfigRequest
UpdateRuntimeTemplateRequest
UploadedSourceBundle
An immutable source archive accepted by the deploy control plane. source_id is content-addressed and can be supplied in SourceRevision to deploy without granting the service access to a Git repository.

Enums

ArtifactPolicyState
BuildBackend
DeploymentPhase
DeploymentStatus
DeploymentStrategy
ErrorCategory
GitLabVisibility
LogStream
OperationState
OwnerKind
OwnerValidationError
PromotionState
ProviderResourceKind
Provider-owned assets projected into Deploy’s tenant ownership boundary.
RuntimeRepositoryStatus

Constants

IDEMPOTENCY_CONFLICT
RUNTIME_TEMPLATE_GIT_REF
VERSION_CONFLICT

Functions

normalize_owners
owners_intersect
parse_provider_backend
provider_backend_name

Type Aliases

ApplicationPage
DeploymentPage
LogPage
ProviderResourcePage
ReleasePage
RuntimeRepositoryRecordPage
RuntimeTemplatePage